@@ -12,12 +12,13 @@ import logging
 
 import pytz
 
+import django.utils.timezone
+
 import mini_buildd.setup
 import mini_buildd.misc
 import mini_buildd.call
 import mini_buildd.changes
 
-import django.utils.timezone
 
 LOG = logging.getLogger(__name__)
 
@@ -217,7 +218,7 @@ $apt_allow_unauthenticated = {apt_allow_unauthenticated};
             sbuild_cmd += ["--run-lintian"]
             # Be sure not to use --suppress-tags when its not availaible (only >=squeeze).
             if mini_buildd.misc.Distribution(self.distribution).has_lintian_suppress():
-                sbuild_cmd += ["--lintian-opts", "--suppress-tags=bad-distribution-in-changes-file,bad-ubuntu-distribution-in-changes-file"]
+                sbuild_cmd += ["--lintian-opts", "--suppress-tags=bad-distribution-in-changes-file"]
             sbuild_cmd += ["--lintian-opts", self._breq["Run-Lintian"]]
 
         if "sbuild" in mini_buildd.setup.DEBUG:
