@@ -398,10 +398,18 @@ class Changes(debian.deb822.Changes):
 
         raise Exception("Buildrequest upload failed for {a}/{c}".format(a=arch, c=codename))
 
-    def tar(self, tar_path, add_files=None, exclude_glob=None):
+    def tar(self, tar_path, add_files=None, exclude_globs=None):
+        exclude_globs = exclude_globs if exclude_globs else []
+
+        def exclude(file_name):
+            for e in exclude_globs:
+                if fnmatch.fnmatch(file_name, e):
+                    return True
+            return False
+
         with contextlib.closing(tarfile.open(tar_path, "w")) as tar:
             def tar_add(file_name):
-                if exclude_glob and fnmatch.fnmatch(file_name, exclude_glob):
+                if exclude(file_name):
                     LOG.info("Excluding \"{f}\" from tar archive \"{tar}\".".format(f=file_name, tar=tar_path))
                 else:
                     tar.add(file_name, arcname=os.path.basename(file_name))
@@ -505,7 +513,7 @@ class Changes(debian.deb822.Changes):
                                     os.path.join(path, "apt_keys"),
                                     chroot_setup_script,
                                     os.path.join(path, "sbuildrc_snippet")] + files_from_pool,
-                         exclude_glob="*.deb")
+                         exclude_globs=["*.deb", "*.changes", "*.buildinfo"])
                 breq.add_file(breq.file_path + ".tar")
 
                 breq["Upload-Result-To"] = daemon.mbd_get_ftp_hopo().string
