@@ -5,13 +5,13 @@ from __future__ import absolute_import
 import tempfile
 import urllib2
 import logging
-import datetime
 import contextlib
 import copy
 
 import django.db.models
 import django.contrib.admin
 import django.contrib.messages
+import django.utils.timezone
 
 import debian.deb822
 
@@ -66,15 +66,15 @@ Use the 'directory' notation with exactly one trailing slash (like 'http://examp
         def mbd_meta_add_debian(cls, msglog):
             "Add internet Debian archive sources."
             for url in ["http://ftp.debian.org/debian/",                                 # Debian Releases
-                        "http://httpredir.debian.org/debian/",                           # alt: httpredir
+                        "http://deb.debian.org/debian/",                                 # alt: CDN
                         "http://ftp.de.debian.org/debian/",                              # alt: full mirror
 
                         "http://archive.debian.org/debian/",                             # Archived Debian Releases
-                        "http://httpredir.debian.org/debian-archive/debian/",            # alt: httpredir
+                        "http://deb.debian.org/debian-archive/debian/",                  # alt: new CDN
                         "http://ftp.de.debian.org/debian-archive/debian/",               # alt: full mirror
 
                         "http://archive.debian.org/debian-backports/",                   # Archived Debian Backports
-                        "http://httpredir.debian.org/debian-archive/debian-backports/",  # alt: httpredir
+                        "http://deb.debian.org/debian-archive/debian-backports/",        # alt: new CDN
                         "http://ftp.de.debian.org/debian-archive/debian-backports/",     # alt: full mirror
                        ]:
                 cls._mbd_get_or_create(msglog, url)
@@ -130,7 +130,7 @@ Use the 'directory' notation with exactly one trailing slash (like 'http://examp
     def mbd_ping(self, request):
         "Ping and update the ping value."
         try:
-            t0 = datetime.datetime.now()
+            t0 = django.utils.timezone.now()
             # Append dists to URL for ping check: Archive may be
             # just fine, but not allow to access to base URL
             # (like ourselves ;). Any archive _must_ have dists/ anyway.
@@ -142,7 +142,7 @@ Use the 'directory' notation with exactly one trailing slash (like 'http://examp
                 if not 400 <= e.code <= 499:
                     raise
 
-            delta = datetime.datetime.now() - t0
+            delta = django.utils.timezone.now() - t0
             self.ping = mini_buildd.misc.timedelta_total_seconds(delta) * (10 ** 3)
             self.save()
             MsgLog(LOG, request).debug("{s}: Ping!".format(s=self))
@@ -279,70 +279,92 @@ codeversion is only used for base sources.""")
         @classmethod
         def mbd_meta_add_debian(cls, msglog):
             """
-            Add well-known Debian sources
+            Add well-known Debian sources.
 
-            7638D0442B90D010: Debian Archive Automatic Signing Key (8/jessie) <ftpmaster@debian.org>
-            CBF8D6FD518E17E1: Jessie Stable Release Key <debian-release@lists.debian.org>
+            To display the key ids via apt-key in the format as used here::
 
-            8B48AD6246925553: Debian Archive Automatic Signing Key (7.0/wheezy) <ftpmaster@debian.org>
-            6FB2A1C265FFB764: Wheezy Stable Release Key <debian-release@lists.debian.org>
+              apt-key adv --list-public-keys --keyid-format=long
 
-            AED4B06F473041FA: Debian Archive Automatic Signing Key (6.0/squeeze) <ftpmaster@debian.org>
-            64481591B98321F9: Squeeze Stable Release Key <debian-release@lists.debian.org>
             """
+
+            keys = {
+                "archive_stretch": "E0B11894F66AEC98",    # Debian Archive Automatic Signing Key (9/stretch) <ftpmaster@debian.org>
+                "release_stretch": "EF0F382A1A7B6500",    # Debian Stable Release Key (9/stretch) <debian-release@lists.debian.org>
+                "archive_jessie": "7638D0442B90D010",     # Debian Archive Automatic Signing Key (8/jessie) <ftpmaster@debian.org>
+                "release_jessie": "CBF8D6FD518E17E1",     # Jessie Stable Release Key <debian-release@lists.debian.org>
+                "archive_wheezy": "8B48AD6246925553",     # Debian Archive Automatic Signing Key (7.0/wheezy) <ftpmaster@debian.org>
+                "release_wheezy": "6FB2A1C265FFB764",     # Wheezy Stable Release Key <debian-release@lists.debian.org>
+                "archive_squeeze": "AED4B06F473041FA",    # Debian Archive Automatic Signing Key (6.0/squeeze) <ftpmaster@debian.org>
+                "release_squeeze": "64481591B98321F9"     # Squeeze Stable Release Key <debian-release@lists.debian.org>
+            }
+
             cls._mbd_get_or_create(msglog, "Debian", "squeeze",
-                                   ["AED4B06F473041FA", "64481591B98321F9"])
-            cls._mbd_get_or_create(msglog, "Debian", "wheezy",
-                                   ["8B48AD6246925553", "6FB2A1C265FFB764", "7638D0442B90D010"])
-            cls._mbd_get_or_create(msglog, "Debian", "jessie",
-                                   ["8B48AD6246925553", "CBF8D6FD518E17E1", "7638D0442B90D010"])
-            cls._mbd_get_or_create(msglog, "Debian", "stretch",
-                                   ["8B48AD6246925553", "7638D0442B90D010"])
-            cls._mbd_get_or_create(msglog, "Debian", "sid",
-                                   ["8B48AD6246925553", "6FB2A1C265FFB764", "7638D0442B90D010"])
+                                   [keys["archive_squeeze"], keys["release_squeeze"]])
             cls._mbd_get_or_create(msglog, "Debian Backports", "squeeze-backports",
-                                   ["AED4B06F473041FA", "8B48AD6246925553"])
+                                   [keys["archive_squeeze"], keys["archive_wheezy"]])
+
+            cls._mbd_get_or_create(msglog, "Debian", "wheezy",
+                                   [keys["archive_wheezy"], keys["release_wheezy"], keys["archive_jessie"]])
             cls._mbd_get_or_create(msglog, "Debian Backports", "wheezy-backports",
-                                   ["8B48AD6246925553", "6FB2A1C265FFB764", "7638D0442B90D010"])
+                                   [keys["archive_wheezy"], keys["release_wheezy"], keys["archive_jessie"]])
             cls._mbd_get_or_create(msglog, "Debian Backports", "wheezy-backports-sloppy",
-                                   ["8B48AD6246925553", "7638D0442B90D010"])
+                                   [keys["archive_wheezy"], keys["archive_jessie"]])
+
+            cls._mbd_get_or_create(msglog, "Debian", "jessie",
+                                   [keys["archive_wheezy"], keys["release_jessie"], keys["archive_jessie"]])
             cls._mbd_get_or_create(msglog, "Debian Backports", "jessie-backports",
-                                   ["8B48AD6246925553", "7638D0442B90D010"])
+                                   [keys["archive_wheezy"], keys["archive_jessie"]])
+            cls._mbd_get_or_create(msglog, "Debian Backports", "jessie-backports-sloppy",
+                                   [keys["archive_wheezy"], keys["archive_jessie"]])
+
+            cls._mbd_get_or_create(msglog, "Debian", "stretch",
+                                   [keys["archive_wheezy"], keys["archive_jessie"], keys["release_jessie"], keys["release_stretch"]])
+            cls._mbd_get_or_create(msglog, "Debian Backports", "stretch-backports",
+                                   [keys["archive_wheezy"], keys["archive_jessie"]])
+
+            cls._mbd_get_or_create(msglog, "Debian", "buster",
+                                   [keys["archive_jessie"], keys["release_jessie"], keys["release_stretch"]])
+
+            cls._mbd_get_or_create(msglog, "Debian", "sid",
+                                   [keys["archive_wheezy"], keys["release_wheezy"], keys["archive_jessie"]])
 
         @classmethod
         def mbd_meta_add_ubuntu(cls, msglog):
-            "Add well-known Ubuntu sources"
+            "Add well-known Ubuntu sources."
+
+            keys = {
+                "archive_current": "40976EAF437D05B5",    # Ubuntu Archive Automatic Signing Key <ftpmaster@ubuntu.com>
+                "archive_2012": "3B4FE6ACC0B21F32",       # Ubuntu Archive Automatic Signing Key (2012) <ftpmaster@ubuntu.com>
+            }
+
+            # trusty: 14.04 (LTS until 2019)
             cls._mbd_get_or_create(msglog, "Ubuntu", "trusty",
-                                   ["40976EAF437D05B5", "3B4FE6ACC0B21F32"])
+                                   [keys["archive_current"], keys["archive_2012"]])
             cls._mbd_get_or_create(msglog, "Ubuntu", "trusty-backports",
-                                   ["40976EAF437D05B5", "3B4FE6ACC0B21F32"],
+                                   [keys["archive_current"], keys["archive_2012"]],
                                    "Codename: trusty\nSuite: trusty-backports")
-            cls._mbd_get_or_create(msglog, "Ubuntu", "utopic",
-                                   ["40976EAF437D05B5", "3B4FE6ACC0B21F32"])
-            cls._mbd_get_or_create(msglog, "Ubuntu", "utopic-backports",
-                                   ["40976EAF437D05B5", "3B4FE6ACC0B21F32"],
-                                   "Codename: utopic\nSuite: utopic-backports")
-            cls._mbd_get_or_create(msglog, "Ubuntu", "vivid",
-                                   ["40976EAF437D05B5", "3B4FE6ACC0B21F32"])
-            cls._mbd_get_or_create(msglog, "Ubuntu", "vivid-backports",
-                                   ["40976EAF437D05B5", "3B4FE6ACC0B21F32"],
-                                   "Codename: vivid\nSuite: vivid-backports")
-            cls._mbd_get_or_create(msglog, "Ubuntu", "wily",
-                                   ["40976EAF437D05B5", "3B4FE6ACC0B21F32"])
-            cls._mbd_get_or_create(msglog, "Ubuntu", "wily-backports",
-                                   ["40976EAF437D05B5", "3B4FE6ACC0B21F32"],
-                                   "Codename: wily\nSuite: wily-backports")
+
+            # xenial: 16.04 (LTS until 2018)
             cls._mbd_get_or_create(msglog, "Ubuntu", "xenial",
-                                   ["40976EAF437D05B5", "3B4FE6ACC0B21F32"])
+                                   [keys["archive_current"], keys["archive_2012"]])
             cls._mbd_get_or_create(msglog, "Ubuntu", "xenial-backports",
-                                   ["40976EAF437D05B5", "3B4FE6ACC0B21F32"],
+                                   [keys["archive_current"], keys["archive_2012"]],
                                    "Codename: xenial\nSuite: xenial-backports")
+
+            # yakkety: 16.10
             cls._mbd_get_or_create(msglog, "Ubuntu", "yakkety",
-                                   ["40976EAF437D05B5", "3B4FE6ACC0B21F32"])
+                                   [keys["archive_current"], keys["archive_2012"]])
             cls._mbd_get_or_create(msglog, "Ubuntu", "yakkety-backports",
-                                   ["40976EAF437D05B5", "3B4FE6ACC0B21F32"],
+                                   [keys["archive_current"], keys["archive_2012"]],
                                    "Codename: yakkety\nSuite: yakkety-backports")
 
+            # zesty: 17.04
+            cls._mbd_get_or_create(msglog, "Ubuntu", "zesty",
+                                   [keys["archive_current"], keys["archive_2012"]])
+            cls._mbd_get_or_create(msglog, "Ubuntu", "zesty-backports",
+                                   [keys["archive_current"], keys["archive_2012"]],
+                                   "Codename: zesty\nSuite: zesty-backports")
+
         @classmethod
         def mbd_filter_active_base_sources(cls):
             "Filter active base sources; needed in chroot and distribution wizards."
