@@ -1,5 +1,6 @@
 # -*- coding: utf-8 -*-
 from __future__ import unicode_literals
+from __future__ import absolute_import
 
 import sys
 import logging
@@ -9,7 +10,7 @@ FOREGROUND = False
 
 HTTPD_BIND = None
 
-# Global directory paths
+#: Global directory paths
 HOME_DIR = None
 
 INCOMING_DIR = None
@@ -21,11 +22,11 @@ LOG_DIR = None
 LOG_FILE = None
 ACCESS_LOG_FILE = None
 CHROOTS_DIR = None
-CHROOT_LIBDIR = None
+CHROOTS_LIBDIR = None
 
 MANUAL_DIR = None
 
-# This should never ever be changed
+#: This should never ever be changed
 CHAR_ENCODING = "UTF-8"
 
 # Compute python-version dependent install path
